import java.util.*;

import wordcram.*;
WordCram wordCram;
/*
How to make a wordcram that pops up extra information
when you click on a word.

Each frame, we want to draw the wordcram, and some info
about the word that's been clicked on (or hovered over).
Each frame, you need to clean up what the last frame drew.

Since laying out a wordcram is expensive, and there's
(currently) no way to quickly re-render a wordcram, 
we don't want to make the wordcram in draw().
(Besides, each frame would probably come out different.)
Instead, render the wordcram in the setup() method, and 
cache it as a PImage. Then, in draw(), render that image
first, which will overlay the last frame's image.



*/

int rows = 1;
int cols = 6;
ArrayList<Image> imgs;

 // We'll ask the wordcram which word is at the mouse coordinates
PImage cachedImage; // Cache the rendered wordcram, so drawing is fast
Word lastClickedWord; // The word that was under the user's last click

PImage background;

String imgPath = ""; 
int imgsCnt = 6; // number of images to be rendered
int imgSize = 200;
ArrayList<Integer> imgIds;

PFont mono;
boolean loadFromCache = false;

void setup() {
  size(1200, 1200);
  //surface.setResizable(true);
  
  initWordCram();
  // wordCram.drawAll();
  
  // Save the image of the wordcram
  
  // Save the image of the wordcram
 // cachedImage = get();

  
  // Set up styles for when we draw stuff to the screen (later)
  textFont(createFont("sans", 150));
  textAlign(CENTER, CENTER);
  
  println(sketchPath(""));
  imgPath = sketchPath("") +"Data/Images/";
  // load the images
  imgs = loadImagesWithTags();
  
   background = loadImage("seat1.png");
   background.resize(width, height);
  // Render the background
    image(background, 0, 0);
    
    //Select Images to render 
 imgIds =  generateUniqueRandomNumbers(0, imgs.size()-1, 10);
 
 // Load the same font used by word cram
  mono = createFont("LiberationSerif-Regular.ttf", 1);
  textFont(mono);
  
  // Draw the title in the middle of the screen
  textSize(40);
  text("Why do people like the Seattle Public Library?", width/2, height/4);
  
}

void draw() {
  //image(background, 0, 0);
 
  
   //Draw the words
   //wordCram.drawAll();
 if (wordCram.hasMore()) {
    wordCram.drawNext();
  }
  
  

  
 // image(cachedImage, 0, 0);
  // If the user's last click was on a word, render it big and blue:
  if (lastClickedWord != null) {
    noStroke();
    fill(255, 190);
    rect(0, height/2 - textAscent()/2, width, textAscent() + textDescent());

    fill(30, 144, 13, 150);
    text(lastClickedWord.word, width/2, height/2);
  }
  
  
  
  // Draw the images
     int index = 0;
    for (int i = 0; i< rows; ++i)
    {
      for (int j = 0; j< cols; ++j)
      {
        Image imgInList = imgs.get(imgIds.get(index++));
        PImage img = imgInList.image;
        img.resize(imgSize, imgSize);
        float x = 0+imgSize*j;
        float y = 0+imgSize*i;
        image(img, x, y);
        imgInList.setPos(x, y, 0);
        textSize(18);
        color c = background.get((int)x, (int)y+imgSize);
          fill(c);
          noStroke();
          rect(x, y+imgSize, imgSize, 60);
        if (imgInList.imageTag != "")
        {
          textAlign(LEFT, LEFT);
          textFont(mono, 18);
          fill(255);
          text(imgInList.imageTag, x, y+imgSize, imgSize, 60);
        }
        
      }
    }
    
    
  
  
}

void mouseClicked() {
  lastClickedWord = wordCram.getWordAt(mouseX, mouseY);
}
void initWordCram() {
  wordCram = new WordCram(this)
      .fromTextFile("reviewTagsTxt.txt")
      .withFont(createFont("LiberationSerif-Regular.ttf", 1))
      .sizedByWeight(10, 90)
      .withColors(color(0, 250, 200), color(30), color(170, 230, 200));
}